==> sword-1.5.4.tar.gz: sword-1.5.4/apps/windoze/CBuilder5/BibleCS/PrintFrm.h <==
//---------------------------------------------------------------------------

#ifndef PrintFrmH
#define PrintFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <ComCtrls.hpp>
#include <ExtCtrls.hpp>
#include <Menus.hpp>
#include "RxRichEditX.h"
#include <Dialogs.hpp>
#include "RxCombos.hpp"
#include <swmodule.h>

typedef struct tagTPageOffset {
        long int Start;
        long int End;
        RECT rendRect;
} TPageOffsets;

//---------------------------------------------------------------------------
class TPrintForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPageControl *PageControl1;
	TTabSheet *shtSelection;
	TTabSheet *shtSetup;
	TBitBtn *btnPrint;
	TBitBtn *btnSetup;
	TBitBtn *btnPreview;
	TBitBtn *btnClose;
	TGroupBox *GroupBox1;
	TRadioButton *radText;
	TRadioButton *radComm;
	TRadioButton *radLD;
	TGroupBox *GroupBox2;
	TEdit *editStart;
	TLabel *staticRange;
	TComboBox *cmbModule;
	TLabel *lblModName;
	TGroupBox *GroupBox3;
	TGroupBox *GroupBox4;
	TGroupBox *GroupBox5;
	TLabel *labelLeft;
	TLabel *labelBot;
	TLabel *labelRight;
	TLabel *labelTop;
	TEdit *editLeft;
	TUpDown *spinLeft;
	TEdit *editBottom;
	TUpDown *spinBottom;
	TEdit *editTop;
	TUpDown *spinTop;
	TEdit *editRight;
	TUpDown *spinRight;
	TLabel *labelHeader;
	TLabel *labelFooter;
	TEdit *editHeader;
	TEdit *editFooter;
	TLabel *Label10;
	TLabel *Label11;
	TLabel *Label12;
	TUpDown *UpDown5;
	TEdit *editHeading;
	TUpDown *UpDown6;
	TEdit *editBody;
	TUpDown *UpDown7;
	TEdit *editNumbers;
	TPrinterSetupDialog *PrinterSetupDialog;
	TLabel *labelFont;
	TPanel *pnlFontComboBox;
	TCheckBox *ckChHead;
	TCheckBox *ckPrefix;
	TCheckBox *ckParagraph;
	TCheckBox *ckPostfix;
	TCheckBox *ckVSNum;
	TCheckBox *ckSuperVS;
	TTabSheet *shtFormat;
	TCheckBox *ckBookHead;
	TCheckBox *ckHeader;
	TCheckBox *ckFooter;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall btnCloseClick(TObject *Sender);
	void __fastcall radTextClick(TObject *Sender);
	void __fastcall radCommClick(TObject *Sender);
	void __fastcall radLDClick(TObject *Sender);
	void __fastcall spinLeftClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spinRightClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spinBottomClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spinTopClick(TObject *Sender, TUDBtnType Button);
	void __fastcall btnPrintClick(TObject *Sender);
   	void __fastcall OnPrint(TRxRichEdit* rtfPrint);
	void __fastcall btnSetupClick(TObject *Sender);
	void __fastcall BitBtn5Click(TObject *Sender);
	void __fastcall btnPreviewClick(TObject *Sender);
	void __fastcall ckHeaderClick(TObject *Sender);
	void __fastcall ckFooterClick(TObject *Sender);
	void __fastcall ckVSNumClick(TObject *Sender);
private:	// User declarations
public:		// User declarations
	TFontComboBox *cmbFont;
	TRxRichEditX* rtfPrint;
	__fastcall TPrintForm(TComponent* Owner);
	void FillModuleCombo();
	void SetHint();
	void PrepareRTF();
	void SetDefaultOps();
	void print(ListKey *keys = 0, SWModule *module = 0);
};
//---------------------------------------------------------------------------
extern PACKAGE TPrintForm *PrintForm;
//---------------------------------------------------------------------------
#endif

==> sword-1.5.6.tar.gz: sword-1.5.6/apps/windoze/CBuilder5/BibleCS/PrintFrm.h <==
//---------------------------------------------------------------------------

#ifndef PrintFrmH
#define PrintFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <ComCtrls.hpp>
#include <ExtCtrls.hpp>
#include <Menus.hpp>
#include "RxRichEditX.h"
#include <Dialogs.hpp>
#include "RxCombos.hpp"
#include <swmodule.h>

typedef struct tagTPageOffset {
        long int Start;
        long int End;
        RECT rendRect;
} TPageOffsets;

//---------------------------------------------------------------------------
class TPrintForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPageControl *PageControl1;
	TTabSheet *shtSelection;
	TTabSheet *shtSetup;
	TBitBtn *btnPrint;
	TBitBtn *btnSetup;
	TBitBtn *btnPreview;
	TBitBtn *btnClose;
	TGroupBox *GroupBox1;
	TRadioButton *radText;
	TRadioButton *radComm;
	TRadioButton *radLD;
	TGroupBox *GroupBox2;
	TEdit *editStart;
	TLabel *staticRange;
	TComboBox *cmbModule;
	TLabel *lblModName;
	TGroupBox *GroupBox3;
	TGroupBox *GroupBox4;
	TGroupBox *GroupBox5;
	TLabel *labelLeft;
	TLabel *labelBot;
	TLabel *labelRight;
	TLabel *labelTop;
	TEdit *editLeft;
        TUpDown *spnLeft;
	TEdit *editBottom;
        TUpDown *spnBottom;
	TEdit *editTop;
        TUpDown *spnTop;
	TEdit *editRight;
        TUpDown *spnRight;
	TLabel *labelHeader;
	TLabel *labelFooter;
	TEdit *editHeader;
	TEdit *editFooter;
	TLabel *Label10;
	TLabel *Label11;
	TLabel *Label12;
        TUpDown *spnHeading;
	TEdit *editHeading;
        TUpDown *spnBody;
	TEdit *editBody;
        TUpDown *spnNumbers;
	TEdit *editNumbers;
	TPrinterSetupDialog *PrinterSetupDialog;
	TLabel *labelFont;
	TPanel *pnlFontComboBox;
	TCheckBox *ckChHead;
	TCheckBox *ckPrefix;
	TCheckBox *ckParagraph;
	TCheckBox *ckPostfix;
	TCheckBox *ckVSNum;
	TCheckBox *ckSuperVS;
	TTabSheet *shtFormat;
	TCheckBox *ckBookHead;
	TCheckBox *ckHeader;
	TCheckBox *ckFooter;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall btnCloseClick(TObject *Sender);
	void __fastcall radTextClick(TObject *Sender);
	void __fastcall radCommClick(TObject *Sender);
	void __fastcall radLDClick(TObject *Sender);
	void __fastcall spnLeftClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spnRightClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spnBottomClick(TObject *Sender, TUDBtnType Button);
	void __fastcall spnTopClick(TObject *Sender, TUDBtnType Button);
	void __fastcall btnPrintClick(TObject *Sender);
   	void __fastcall OnPrint(TRxRichEdit* rtfPrint);
	void __fastcall btnSetupClick(TObject *Sender);
	void __fastcall btnPreviewClick(TObject *Sender);
	void __fastcall ckHeaderClick(TObject *Sender);
	void __fastcall ckFooterClick(TObject *Sender);
	void __fastcall ckVSNumClick(TObject *Sender);
private:
	void SavePrintPrefs();
        int inline GetSpinPos(const float & value);
        float roundMargin(float value);	// User declarations
public:		// User declarations
	TFontComboBox *cmbFont;
	TRxRichEditX* rtfPrint;
	__fastcall TPrintForm(TComponent* Owner);
	void FillModuleCombo();
	void SetHint();
	void PrepareRTF();
	void SetDefaultOps();
	void print(ListKey *keys = 0, SWModule *module = 0);
};
//---------------------------------------------------------------------------
extern PACKAGE TPrintForm *PrintForm;
//---------------------------------------------------------------------------
#endif
